@@ -14,6 +14,14 @@ class RemoteTransferHandler(ABC):
     def transfer_files(self, files, dest_remote_handler=None):
         ...
 
+    @abstractmethod
+    def push_files_from_worker(self, files, dest_remote_handler=None):
+        ...
+
+    @abstractmethod
+    def pull_files_to_worker(self, files, local_staging_directory):
+        ...
+
     @abstractmethod
     def pull_files(self, files):
         ...
